from setuptools import setup

setup(name='gbjl_probability',
      version='0.1',
      description='Analyze Gaussian and Binomial distributions',
      packages=['gbjl_probability'],
      author='Jorge Nustes',
      author_email='jlnustes@gmail.com',
      zip_safe=False)
